# mkeima: Analyze flow cytometry-based mKeima assays in Python

[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)


**mkeima** is a Python library for the analysis and visualization of data from flow cytometry-based mKeima assays.


## Installing mkeima

If you do not already have a Python installation, we recommend installing the [Anaconda distribution](https://www.continuum.io/downloads) of Continuum Analytics, which already contains a large number of popular Python packages for Data Science. Alternatively, you can also get Python from the [Python homepage](https://www.python.org/downloads/windows).

*Note* that the mkeima package requires Python version 3.9 or higher.

You can use pip to install mkeima from the [Python Package Index](https://pypi.org/)

```
pip install mkeima
```

To uninstall the mkeima package run the following command:

```
pip uninstall mkeima
```

### Installation when using Anaconda
If you are using Anaconda, you will need to install the mkeima package into a conda environment. Open the Anaconda navigator, activate the conda environment you want to use, run the "CMD.exe" application to open a terminal, and then use the pip install command as described above.

## Future updates
- Release source code on GitHub, including example data and jupyter notebooks to demonstrate the use of the package.

## License
mkeima is licensed under the [Apache License 2.0](http://www.apache.org/licenses/LICENSE-2.0.txt).


## Contributors
David M. Hollenstein https://github.com/hollenstein
